==> chpasswd-2.2.2.tar.gz: chpasswd-2.2.2/Polish.h <==
/* Polish language added by Tomasz Przewlucki <tomek@sprint.com.pl> */

#if defined(Polish)

char *msg01 = "Brak praw zapisu do pliku:";
char *msg02 = "Nowe haso bldne lub zbyt krtkie (min.";
char *msg03 = "znakw).";
char *msg04 = "Nowe haso jest zbyt dugie (max.";
char *msg05 = "Prosz uy nowego hasa!!!";
char *msg06 = "Bad weryfikacji hasa! Wpisz dwa razy dokadnie to samo haso.";
char *msg07 = "Bad podczas otwierania pliku hase:";
char *msg08 = "Bad podczas otwierania pliku tymczasowego.";
char *msg09 = "Podano nieprawidowe haso dla uytkownika:";
char *msg10 = "Haso nie zostao zmienione.";
char *msg11 = "Zmieniono haso uytkownika";
char *msg12 = "";
char *msg13 = "Uytkownik:";
char *msg14 = "nie odnaleziony.";
char *msg15 = "Bad podczas otwierania pliku konfiguracyjnego:";
char *msg16 = "Bad podczas otwierania pliku logowania:";
char *msg17 = "Wpisane, nowe haso jest nieprawidowe.";
char *msg18 = "Prosz uwzgldni ponisze zasady przy ustalaniu nowego hasa:";
char *msg19 = "Minimalna liczba liter (a-z, A-Z)";
char *msg20 = "Minimalna liczba cyfr (0-9)";
char *msg21 = "Minimalna liczba znakw specjalnych (z klawiatury)";
char *msg22 = "Zmie swoje haso uytkownika serwera W3Cache";
char *msg23 = "Wascicielem pliku autoryzacji musi byc root. Prosz przeczyta README.";
char *msg24 = "Nieprawidowe prawa pliku autoryzacji (chmod 755). Prosz przeczytac README.";
char *msg25 = "Bad podczas otwierania pliku autoryzacji.";
char *msg26 = "Nie posiadasz uprawnie do zmiany hasa.";
char *msg27 = "Plik autoryzacji nie odnaleziony.";

static void UserForm(char *minlen, char *maxlen, char *minchar, char *minnum, char *minspec, char *bgcolor, char *txcolor, char *ticolor, char *rucolor, char *logo, char *width, char *height, char *header, char *bgimage, char *ShowInfo)
{

  char rules[255] = "<li>Zawartosc:";
  char wrules[255];
  int  frules=0;

  printf("Content-type: text/html\n");
  puts("\n");
  printf("<html>\n");
  printf("<head>\n");
  printf("<meta http-equiv=\"content-type\" content=\"text/html; charset=iso-8859-2\">\n");
  printf("  <title>Zmiana hasa uytkownika serwera W3Cache</title>\n");
  printf("</head>\n");
  printf("<body bgcolor=%s text=%s background='%s'>\n",bgcolor,txcolor,bgimage);

  if(strlen(logo) > 0)
     printf("<h2><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font></h2>\n",logo,width,height,ticolor,header);
   else
     printf("<h2><font color=%s>%s</font></h2>\n",ticolor,header);

  printf("Wedug wymogw bezpieczestwa, podczas ustalania hasa wez pod uwag nastpujace zasady:\n");
  printf("<ul>\n");
  printf("<li>Przy wpisywaniu hasa wana jest wielkosc liter - czyli ''A' to nie to samo co 'a'.<br>\n");
  printf("<li>Moesz uywa liter, cyfr i innych znakw specjalnych z klawiatury.<br>\n");
  printf("<li>Nowe haso musi zawiera:<br>");
  printf("<ul><li>Dugosc: min. <font color=%s><b>%s</b></font>, max. <font color=%s><b>%s</b></font> znakw.<br>\n",rucolor,minlen,rucolor,maxlen);

  if(strcmp(minchar,"0") != 0) {
     sprintf(wrules," litery (a-z, A-Z):<font color=%s><b> %s</b></font>",rucolor,minchar);
     strcat(rules,wrules);
     frules=1;
  }
  if(strcmp(minnum,"0") != 0) {
     if(frules)
        strcat(rules,", ");
     sprintf(wrules," cyfry (0-9):<font color=%s><b> %s</b></font>",rucolor,minnum);
     strcat(rules,wrules);
     frules=1;
  }
  if(strcmp(minspec,"0") != 0) {
     if(frules)
        strcat(rules,", ");
     sprintf(wrules," znaki specjalne (z klawiatury):<font color=%s><b> %s</b></font>",rucolor,minspec);
     strcat(rules,wrules);
     frules=1;
  }
  if(!frules){
     sprintf(wrules,"<font color=%s><b> Dowolny wybr</b></font>",rucolor);
     strcat(rules,wrules);
  }
  strcat(rules,"<br>");
  printf(rules);
  printf("</ul>\n");

  printf("<li>Nowe haso powinno by aktywne po okoo 15 minutach.\n");
  printf("</ul>\n");
  printf("<form action='chpasswd.cgi' method=POST>\n");
  printf("<center>\n");
  printf("<hr noshade>\n");
  printf("<table cellpadding=0 cellspacing=0>\n");
  printf("  <tr><td align=right>Nazwa uytkownika:\n");
  printf("      <td><input type=text name=user size=10>\n");
  printf("  <tr><td align=right>Dotychczasowe haso:\n");
  printf("      <td><input type=password name=old_pw size=%s>\n",maxlen);
  printf("  <tr><td align=right>Nowe haso:\n");
  printf("      <td><input type=password name=new_pw1 size=%s>\n",maxlen);
  printf("  <tr><td align=right>Nowe haso (weryfikacja):\n");
  printf("      <td><input type=password name=new_pw2 size=%s>\n",maxlen);
  printf("</table>\n");
  printf("<hr noshade>\n");
  printf("<input type=submit name=change value='Zmien haso!'>\n");
  printf("<input type=reset name=reset value='Czysc pola'>\n");
  printf("<input type=submit name=cancel value='Anuluj'>\n");
  printf("</center>\n");
  printf("</form>\n");
  if(strcmp(ShowInfo,"on") == 0)
     printf("<font size=-2><a href='%s'>%s-%s</a></font>\n",URL,PGM,VERSION);
  printf("</body>\n");
  printf("</html>\n");

  fflush(stdout);
  return;

}
#endif

==> chpasswd-2.2.4.tar.gz: chpasswd-2.2.4/Polish.h <==
/* Polish language added by Tomasz Przewlucki <tomek@sprint.com.pl> */

#if defined(Polish)

char *msg01 = "Brak praw zapisu do pliku:";
char *msg02 = "Nowe haso bldne lub zbyt krtkie (min.";
char *msg03 = "znakw).";
char *msg04 = "Nowe haso jest zbyt dugie (max.";
char *msg05 = "Prosz uy nowego hasa!!!";
char *msg06 = "Bad weryfikacji hasa! Wpisz dwa razy dokadnie to samo haso.";
char *msg07 = "Bad podczas otwierania pliku hase:";
char *msg08 = "Bad podczas otwierania pliku tymczasowego.";
char *msg09 = "Podano nieprawidowe haso dla uytkownika:";
char *msg10 = "Haso nie zostao zmienione.";
char *msg11 = "Zmieniono haso uytkownika";
char *msg12 = "";
char *msg13 = "Uytkownik:";
char *msg14 = "nie odnaleziony.";
char *msg15 = "Bad podczas otwierania pliku konfiguracyjnego:";
char *msg16 = "Bad podczas otwierania pliku logowania:";
char *msg17 = "Wpisane, nowe haso jest nieprawidowe.";
char *msg18 = "Prosz uwzgldni ponisze zasady przy ustalaniu nowego hasa:";
char *msg19 = "Minimalna liczba liter (a-z, A-Z)";
char *msg20 = "Minimalna liczba cyfr (0-9)";
char *msg21 = "Minimalna liczba znakw specjalnych (z klawiatury)";
char *msg22 = "Zmie swoje haso uytkownika serwera W3Cache";
char *msg23 = "Wascicielem pliku autoryzacji musi byc root. Prosz przeczyta README.";
char *msg24 = "Nieprawidowe prawa pliku autoryzacji (chmod 755). Prosz przeczytac README.";
char *msg25 = "Bad podczas otwierania pliku autoryzacji.";
char *msg26 = "Nie posiadasz uprawnie do zmiany hasa.";
char *msg27 = "Plik autoryzacji nie odnaleziony.";char *msg28 = "Could not open deny user file.";
char *msg29 = "User not allowed to change password.";

static void UserForm(char *minlen, char *maxlen, char *minchar, char *minnum, char *minspec, char *bgcolor, char *txcolor, char *ticolor, char *rucolor, char *logo, char *width, char *height, char *header, char *bgimage, char *ShowInfo)
{

  char rules[255] = "<li>Zawartosc:";
  char wrules[255];
  int  frules=0;

  printf("Content-type: text/html\n");
  puts("\n");
  printf("<html>\n");
  printf("<head>\n");
  printf("<meta http-equiv=\"content-type\" content=\"text/html; charset=iso-8859-2\">\n");
  printf("  <title>Zmiana hasa uytkownika serwera W3Cache</title>\n");
  printf("</head>\n");
  printf("<body bgcolor=%s text=%s background='%s'>\n",bgcolor,txcolor,bgimage);

  if(strlen(logo) > 0)
     printf("<h2><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font></h2>\n",logo,width,height,ticolor,header);
   else
     printf("<h2><font color=%s>%s</font></h2>\n",ticolor,header);

  printf("Wedug wymogw bezpieczestwa, podczas ustalania hasa wez pod uwag nastpujace zasady:\n");
  printf("<ul>\n");
  printf("<li>Przy wpisywaniu hasa wana jest wielkosc liter - czyli ''A' to nie to samo co 'a'.<br>\n");
  printf("<li>Moesz uywa liter, cyfr i innych znakw specjalnych z klawiatury.<br>\n");
  printf("<li>Nowe haso musi zawiera:<br>");
  printf("<ul><li>Dugosc: min. <font color=%s><b>%s</b></font>, max. <font color=%s><b>%s</b></font> znakw.<br>\n",rucolor,minlen,rucolor,maxlen);

  if(strcmp(minchar,"0") != 0) {
     sprintf(wrules," litery (a-z, A-Z):<font color=%s><b> %s</b></font>",rucolor,minchar);
     strcat(rules,wrules);
     frules=1;
  }
  if(strcmp(minnum,"0") != 0) {
     if(frules)
        strcat(rules,", ");
     sprintf(wrules," cyfry (0-9):<font color=%s><b> %s</b></font>",rucolor,minnum);
     strcat(rules,wrules);
     frules=1;
  }
  if(strcmp(minspec,"0") != 0) {
     if(frules)
        strcat(rules,", ");
     sprintf(wrules," znaki specjalne (z klawiatury):<font color=%s><b> %s</b></font>",rucolor,minspec);
     strcat(rules,wrules);
     frules=1;
  }
  if(!frules){
     sprintf(wrules,"<font color=%s><b> Dowolny wybr</b></font>",rucolor);
     strcat(rules,wrules);
  }
  strcat(rules,"<br>");
  printf(rules);
  printf("</ul>\n");

  printf("<li>Nowe haso powinno by aktywne po okoo 15 minutach.\n");
  printf("</ul>\n");
  printf("<form action='chpasswd.cgi' method=POST>\n");
  printf("<center>\n");
  printf("<hr noshade>\n");
  printf("<table cellpadding=0 cellspacing=0>\n");
  printf("  <tr><td align=right>Nazwa uytkownika:\n");
  printf("      <td><input type=text name=user size=10>\n");
  printf("  <tr><td align=right>Dotychczasowe haso:\n");
  printf("      <td><input type=password name=old_pw size=%s>\n",maxlen);
  printf("  <tr><td align=right>Nowe haso:\n");
  printf("      <td><input type=password name=new_pw1 size=%s>\n",maxlen);
  printf("  <tr><td align=right>Nowe haso (weryfikacja):\n");
  printf("      <td><input type=password name=new_pw2 size=%s>\n",maxlen);
  printf("</table>\n");
  printf("<hr noshade>\n");
  printf("<input type=submit name=change value='Zmien haso!'>\n");
  printf("<input type=reset name=reset value='Czysc pola'>\n");
  printf("<input type=submit name=cancel value='Anuluj'>\n");
  printf("</center>\n");
  printf("</form>\n");
  if(strcmp(ShowInfo,"on") == 0)
     printf("<font size=-2><a href='%s'>%s-%s</a></font>\n",URL,PGM,VERSION);
  printf("</body>\n");
  printf("</html>\n");

  fflush(stdout);
  return;

}
#endif
